CompactError

Enum CompactError 

#[non_exhaustive]
pub enum CompactError { UnknownSchema(SchemaId), BundleSchemaIdMismatch { stated: SchemaId, recomputed: SchemaId, }, Unsupported(&'static str), TypeMismatch { expected: &'static str, }, UnknownVariant(String), BadVariantIndex(u32), GenericArity { params: usize, args: usize, }, Malformed(&'static str), Incompatible(String), WriterOnlyVariant(u32), Decode(DecodeError), Encode(EncodeError), }
Why a compact encode or decode failed.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnknownSchema(SchemaId)

A referenced schema id is not in the registry (r[schema-identity.unknown-is-error]).



BundleSchemaIdMismatch

A received schema bundle member’s stated id did not match its content hash.

Fields

stated: SchemaId
recomputed: SchemaId


Unsupported(&'static str)

A kind or feature not yet implemented in this codec.



TypeMismatch

The value’s shape does not match the schema it is being encoded against.

Fields

expected: &'static str


UnknownVariant(String)

An enum value names a variant the schema does not have.



BadVariantIndex(u32)

A decoded enum variant index is out of range.



GenericArity

A generic schema applied with the wrong number of type arguments.

Fields

params: usize
args: usize


Malformed(&'static str)

A structurally malformed schema (e.g. an unbound type variable, or a primitive carrying type arguments).



Incompatible(String)

Two schemas cannot be translated by a compatibility plan (r[compat.*]).



WriterOnlyVariant(u32)

A decoded enum variant exists in the writer schema but has no counterpart in the reader schema (r[compat.enum]).



Decode(DecodeError)

A decode-side validation failure from the byte reader.



Encode(EncodeError)

A dynamic (self-describing) sub-value failed to encode.