pub enum CompatDirection {
Backward,
Forward,
Bidirectional,
Incompatible,
}Variants
Backward
The newer schema can read bytes written by the older schema.
Forward
The older schema can read bytes written by the newer schema.
Bidirectional
Both schema versions can read each other’s bytes.
Incompatible
Neither schema version can read the other’s bytes.